<%

Class WebSiteSearch
	'#########################
	'#  WebSiteSearch Class  #
	'#  Version 2.0          #
	'#                       ########################################
	'#                                                              #
	'#                                                              #
	'#  Summary:                                                    #
	'#   This class uses the scripting.filesystemobject             #
	'#   to search an array of directories for files                #
	'#   that contain the entered phrase or words based             #
	'#   on various criteria.                                       #
	'#                                                              #
	'#                                                              #
	'#  Notes/Warnings:                                             #
	'#   - This class requires several server-side COM objects to   #
	'#     work properly. The following objects are used:           #
	'#       Scripting.FileSystemObject                             #
	'#       ADODB.Recordset                                        #
	'#                                                              #
	'#   - This system is usually pretty quick however that depends #
	'#     entirely on how many files the system is to search.      #
	'#     Currently, at the ASP Emporium, this system parses about #
	'#     205 documents and returns complete results in about 12   #
	'#     seconds. This is a dramatic improvement over the older   #
	'#     versions although still too slow in my opinion.          #
	'#     The speed issues come from the FileSystemObject as it    #
	'#     just can't gather content any faster from files. I'm     #
	'#     considering writing a COM object to gather the files     #
	'#     but I'm convinced that further speeding up of the system #
	'#     will require some sort of caching system that only has   #
	'#     to scan files whenever something is added or changed.    #
	'#                                                              #
	'#   - Only the latest version of this class is supported. It   #
	'#     is recommended that you upgrade to the newest version    #
	'#     immediately to ensure trouble-free code operation.       #
	'#                                                              #
	'#                                                              #
	'#  Version History:                                            #
	'#   Version 3.0 [January 2003] (rick@eastes.net                #
	'#   -Integrated with nukedit                                    #
	'#   -Search results now feature a preview of the contents      #
	'#   -Only search results that user has permissions to see      #
	'#                                                              #
	'#                                                              #
	'#   Version 2.0 [January 2001]                                 #
	'#    - These has been a change in properties and methods.      #
	'#      MAKE SURE YOU LOOK AT THE PROPERTIES AND METHOD SHEET   #
	'#      BELOW BEFORE USING THIS CLASS WITH RUN-TIME CODE FROM   #
	'#      AN OLDER VERSION.                                       #
	'#    - a simplified programmer's interface with fewer          #
	'#      properties to set before using the class.               #
	'#    - regular-expression based searching of files.            #
	'#    - smart-search: the class will determine on it's own      #
	'#      whether the terms being searched on will be searched    #
	'#      with a WORD or PHRASE query method.                     #
	'#    - results display updated: paged results with user        #
	'#      sorting options. All found documents are referenced by  #
	'#      their HTML titles and by an optional directory          #
	'#      proper-name.                                            #
	'#    - multi-level searching: the new version of WebSiteSearch #
	'#      class no longer relies on a "base directory" as an      #
	'#      entry point to searching a website. This allows any     #
	'#      directory in the site to be searched and also allows    #
	'#      the class to search outside of the virtual web          #
	'#      directory (ie - all of the server's hard drives -       #
	'#      assuming your permissions allow).                       #
	'#    - "Word bug repaired": older versions of the software     #
	'#      didn't return results if only one word is searched on   #
	'#      a Query_Method of "Word".                               #
	'#    - "AND" and "OR" keyword search options were removed. All #
	'#      searches now take a search_type of AND to ensure more   #
	'#      accurate results.                                       #
	'#    - Version 2.0 is faster: parsing and searching 200 files, #
	'#      categorizing them, and displaying results in around 12  #
	'#      seconds. Older versions may have taken up to 30 seconds #
	'#      to do the same work. This speed problem is due to the   #
	'#      fact that the FSO needs a little time to gather and     #
	'#      read 200 files. It works much faster on smaller sites   #
	'#      with fewer pages and slower on sites with more pages    #
	'#      of content to search.                                   #
	'#    - Overall class structure is more mature and stable than  #
	'#      previous versions.                                      #
	'#                                                              #
	'#   Version 1.1 (not publicly released) [September 2000]       #
	'#    - Search results referenced by html title (if any)        #
	'#      and a description consisting of the first 15 or         #
	'#      so words of the html body (if any).                     #
	'#    - Better results display.                                 #
	'#    - Sub folder search expanded to allow multi-level         #
	'#      directories like "examples\jscript" inside the base     #
	'#      directory.                                              #
	'#                                                              #
	'#   Version 1.0 [August 2000]                                  #
	'#    Initial Release.                                          #
	'#                                                              #
	'#                                                              #
	'#  Properties:                                                 #
	'# +-------------------+-----------+--------------------------+ #
	'# |   Property        | Data Type |  Information             | #
	'# +-------------------+-----------+--------------------------+ #
	'# | Search_Extensions | Variant   | Read/Write. Expects an   | #
	'# |                   | (Array)   | array of file extensions | #
	'# |                   |           | to search. These should  | #
	'# |                   |           | be specified without the | #
	'# |                   |           | "." character.           | #
	'# +-------------------+-----------+--------------------------+ #
	'# | Active_Directories| Variant   | Read/Write. Expects an   | #
	'# |                   | (Array)   | array of absolute        | #
	'# |                   |           | directories (starting    | #
	'# |                   |           | with a drive letter) to  | #
	'# |                   |           | search.                  | #
	'# +-------------------+-----------+--------------------------+ #
	'# | Search_Terms      | String    | Read/Write. Sets/Returns | #
	'# |                   |           | the text that the class  | #
	'# |                   |           | will search.             | #
	'# +-------------------+-----------+--------------------------+ #
	'# | ShowParseTime     | Boolean   | Read/Write. Boolean to   | #
	'# |                   |           | indicate whether or not  | #
	'# |                   |           | to time the search.      | #
	'# |                   |           | If set to true, the time | #
	'# |                   |           | in seconds will be       | #
	'# |                   |           | displayed after any      | #
	'# |                   |           | search records.          | #
	'# |                   |           | Default value: False     | #
	'# +-------------------+-----------+--------------------------+ #
	'# | MaxResultsPerPage | Long      | Read/Write. Sets/Returns | #
	'# |                   |           | the number of search     | #
	'# |                   |           | results to show on each  | #
	'# |                   |           | page.                    | #
	'# |                   |           | Default value: 25        | #
	'# +-------------------+-----------+--------------------------+ #
	'# | Version           | String    | Read Only.               | #
	'# |                   |           | Returns "major.minor"    | #
	'# |                   |           | version information.     | #
	'# +-------------------+-----------+--------------------------+ #
	'#                                                              #
	'#                                                              #
	'#  Methods:                                                    #
	'# +----------------+-------------+---------------------------+ #
	'# |    Method      |  Data Type  |  Information              | #
	'# +----------------+-------------+---------------------------+ #
	'# | Perform_Search |  Void       | Performs the website      | #
	'# |(Default method)|             | search and writes search  | #
	'# |                |             | results to the client     | #
	'# |                |             | browser.                  | #
	'# +----------------+-------------+---------------------------+ #
	'#                                                              #
	'################################################################

	Private oRs, objFSOSearch
	Private sBaseQS, sSortQS, hTimer1, hTimer2, bNoSearchArray
	Private iPageSize, iPageCurrent, iPageCount, bUseAsc
	Private Query_Method
	Private SQLMenu,rsMenu

	'-----------------
	'Public Properties
	'-----------------
	Public Search_Extensions
	Public Active_Directory
	Public Search_Terms
	Public ShowParseTime
	Public MaxResultsPerPage


	Public Property Get Version()
		'public read-only version property
		Version = "3.0"
	End Property

	'-----------------
	Public Methods
	'-----------------
	
'	set rsAll=db.execute(sql)

	Public Default Sub Perform_Search
		
		Dim i, objSearchFile, objCurrentSearchFolder

		iPageSize = MaxResultsPerPage

		OpenTmpDatabase
		Pre_Processing

		bNoSearchArray = False
		If Not IsArray(Search_Terms) Then bNoSearchArray = True
		
		 ' get active_directory property input
		 ' and put it into an array.
		 ' look in each specified directory for files to search
		 ' create instance of the FSO object
			Set objFSOSearch = Server.CreateObject("Scripting.FileSystemObject")

			 ' take base directory and each directory in the array
			 ' to make up the folder to open
'			Set objCurrentSearchFolder = objFSOSearch.GetFolder(Active_Directory)

			 ' get each file in the folder to search
'			rsMenu.movefirst
            while(NOT rsMenu.EOF AND NOT rsMenu.BOF)
            
				'response.Write Active_Directory + "\" + replace(rsMenu("data"),"/","\") + "<br>"
				
				on error resume next
				set objSearchFile = GetHandle(Active_Directory + "\" + replace(rsMenu("data"),"","\"))
				
				if((NOT err > 0) AND (IsAllowed(rsMenu("permissions"))> 0))then
					'response.Write objSearchFile & "    *<br>"	
					GatherFileAndParse objSearchFile, Active_Directory
				end if
				err.clear
				on error goto 0
				rsMenu.movenext
			Wend

			 ' release the folder and the FSO,
			 ' freeing memory for the next pass
			Set objCurrentSearchFolder = Nothing
			Set objFSOSearch = Nothing

		WriteResultantDisplay
	End Sub


	'-----------------
	'Class Events
	'-----------------
	Private Sub Class_Initialize()
		'default property settings
		Search_Extensions = Array(".asp")
		Query_Method = "WORD"	'phrase
		Active_Directory = ""
		Search_Terms = ""
		ShowParseTime = False
		MaxResultsPerPage = 25
		SQLMenu = 	"select * from tblMenu"
		set rsMenu=db.execute(SQLMenu)
		
		
		bUseAsc = False

		CreateTmpTable
		sBaseQS = "./search.asp?terms=" & server.urlencode(request("terms"))
		hTimer1 = Timer

		If Request("page") = "" Then iPageCurrent = 1 _
		    Else iPageCurrent = CInt(Request("page"))

		If InStr(Right(UCase( _
		    Request("Sort")), 4), "DESC") = 0 Then bUseAsc = True
	End Sub

	Private Sub Class_Terminate()
		hTimer2 = Timer - hTimer1
		If ShowParseTime Then _
		    Response.Write("Search Took: " & hTimer2 & " seconds")

		oRs.Close
		Set oRs = Nothing
		With Response
		End With
	End Sub


	'-----------------
	'Internal Procedures
	'-----------------
	Private Sub Pre_Processing()
		'This routine fixes any Search_Terms
		'and determines the Query_Method
		'that will be used about the search.

		'Query_Method was removed as a property
		'and all the processing of the Search_Terms
		'property was moved to the class.
		'This routine's logic had to be designed
		'by each user in previous versions.
		'This also changed the data type of the
		'Search_Terms property from a variant
		'accepting either arrays or strings 
		'to a string type (if you want to be
		'picky about it, the Search_Terms
		'property accepts variants of sub-type
		'String and Not variants of sub-type
		'Array. Clear?)
		If InStr(Search_Terms, ",") <> 0 Then
			Search_Terms = Split(Search_Terms, ",")
			Query_Method = "WORD"
		Else
			Search_Terms = Trim(Search_Terms)
			Query_Method = "PHRASE"
		End If
	End Sub

	Private Sub OpenTmpDatabase()
		With oRs
			.PageSize = iPageSize
			.CacheSize = iPageSize
			.Open
		End With
	End Sub

	Private Sub CreateTmpTable()
		Set oRs = Server.CreateObject("ADODB.Recordset")
		With oRs
			.Fields.Append "Page_Path", 200, 255
			.Fields.Append "Page_Title", 200, 255
			.Fields.Append "Page_Type", 200, 255
			.Fields.Append "Page_Content",8
		End With
	End Sub

function GetHandle(txtfile)
	'returns a file object
	dim objFile
	set objFile = FSO.GetFile(txtfile)
	set GetHandle = objFile
end function


function GetContents(objFile)
	dim strContents
	strContents = ""
	Dim TextStream
	Set TextStream = objFile.OpenAsTextStream(1, -2)

	' Read the file line by line
	Do While Not TextStream.AtEndOfStream
		'response.Write TextStream.readline
		strContents = strContents & TextStream.readline
	Loop
	
	'FSO.Close
	'response.Write strContents
	GetContents = strContents
end function

	Private Sub GatherFileAndParse(byRef objSearchFile, byVal i)
		on error goto 0
		Dim m, strTempFile, bDisplayLink, theTitle

		 ' open each file if the extension is to be searched:
		For m = 0 to UBOUND(Search_Extensions)
			content = ""
			If LCase(Search_Extensions(m)) = _
			    LCase(Right(objSearchFile.Name, _
			    Len(objSearchFile.Name) - _
			    InStrRev(objSearchFile.Name, "."))) Then


				'strTempFile = MkTmpFile(Active_Directory & "\content\" & objSearchFile.Name)
				'response.Write "blah<br>"

'				strTempFile = GetContents(site & "content\" & objSearchFile.Name)
				strTempFile = GetContents(objSearchFile)
				
				'response.Write "blah<br>"
				 ' don't display a link by default
				bDisplayLink = False

				 ' check the query_method input
				if UCASE(Query_Method) = "PHRASE" And bNoSearchArray then
					content = PhraseFound(strTempFile, Search_Terms)
					bDisplayLink = len(content) > 0
					
				else
					content = WordsFound(strTempFile, Search_Terms)
					bDisplayLink = len(content) > 0
				end if
				

				theTitle = rsMenu("title")
	
				
				If RedirectFile(theTitle) Then
				    bDisplayLink = False
				end if

				if bDisplayLink then 
					AddSearchResultRecord _
					    EscapeApostrophe(CreateHTTPPath(objSearchFile.Path)), _
					    EscapeApostrophe(theTitle), _
					    EscapeApostrophe(DefineLink(objSearchFile.Path)), _
					    EscapeApostrophe(content)
					    
				end if
				Exit For
			End If
		Next
	End Sub

	Private Sub WriteResultantDisplay()
		 ' write display to the browser
		iPageCount = oRs.PageCount
		If iPageCurrent > iPageCount Then iPageCurrent = iPageCount
		If iPageCurrent < 1 Then iPageCurrent = 1
		If iPageCount = 0 or oRs.BOF Then

			'in the event of no matches:
			ShowNoResults
		else
			ShowDocsFound
			ResolveSortPattern
			'ShowSortOptions
			ShowResults
		end if
	End Sub

	Private Function RedirectFile(sTitle)
		If InStr(PCase(sTitle), "Where Am I") <> 0 then
			RedirectFile = True
		Else
			RedirectFile = False
		End If
	End Function

	Private Function WordsFound(byVal toSrch, byVal toFindArray)
		Dim iPosLinkCt, j, re, content
		content = ""
		foundAt = 0
		toSrch = RemoveASP(toSrch)
		toSrch = RemoveHTML(toSrch)


		 ' for a word search we need to check
		 ' each word in the array
		 ' start count of matched words @ -1
		iPosLinkCt = -1

		 ' check each word in the array
		 ' against the file text
		Set re = New RegExp
		'response.Write toSrch
		With re
			.ignorecase = true
			.global = false
			For j = 0 to UBOUND(toFindArray)
				.pattern = "[\b]*" & EscapeRegExp(toFindArray(j)) & "\b"
				set Matches = .Execute(toSrch)
				
				for each Match in Matches
					foundAt =  Match.FirstIndex
		
					if(foundAt < (gs_PreviewSize/2) AND foundAt > 0)then
							foundAt = (gs_PreviewSize/2 + 1)
					end if		
					endpreview = gs_PreviewSize
					
					content = content + Highlight(Mid( toSrch, foundAt - (gs_PreviewSize/2), endpreview), toFindArray(j), "<b>", "</b>")
				Next
				If .test(toSrch) Then
					iPosLinkCt = iPosLinkCt + 1
				end if		
				'response.Write content		 
			Next
		End With
		Set re = Nothing
		If CLng(iPosLinkCt) >= CLng(UBound(toFindArray)) Then
			WordsFound = content
		Else
			WordsFound = content
		End If
	End Function
	
	Private Function RemoveHTML( strText )
		strText = Replace(strText,"<BR  /><BR  />","<BR>")
    Dim TAGLIST
    TAGLIST = ";!--#include;!--;!DOCTYPE;A;ACRONYM;ADDRESS;APPLET;AREA;B;BASE;BASEFONT;" &_
              "BGSOUND;BIG;BLOCKQUOTE;BODY;BUTTON;CAPTION;CENTER;CITE;CODE;" &_
              "COL;COLGROUP;COMMENT;DD;DEL;DFN;DIR;DIV;DL;DT;EM;EMBED;FIELDSET;" &_
              "FONT;FORM;FRAME;FRAMESET;HEAD;H1;H2;H3;H4;H5;H6;HR;HTML;I;IFRAME;IMG;" &_
              "INPUT;INS;ISINDEX;KBD;LABEL;LAYER;LAGEND;LINK;LISTING;MAP;P;MARQUEE;" &_
              "MENU;META;NOBR;NOFRAMES;NOSCRIPT;OBJECT;OL;OPTION;PARAM;PLAINTEXT;" &_
              "PRE;Q;S;SAMP;SCRIPT;SELECT;SMALL;SPAN;STRIKE;STRONG;STYLE;SUB;SUP;" &_
              "TABLE;TBODY;TD;TEXTAREA;TFOOT;TH;THEAD;TITLE;TR;TT;U;VAR;WBR;XMP;"

    Const BLOCKTAGLIST = ";APPLET;EMBED;FRAMESET;HEAD;NOFRAMES;NOSCRIPT;OBJECT;SCRIPT;STYLE;%;"
    
    Dim nPos1
    Dim nPos2
    Dim nPos3
    Dim strResult
    Dim strTagName
    Dim bRemove
    Dim bSearchForBlock
    
    '
    
    nPos1 = InStr(strText, "<")
    Do While nPos1 > 0
        nPos2 = InStr(nPos1 + 1, strText, ">")
        If nPos2 > 0 Then
            strTagName = Mid(strText, nPos1 + 1, nPos2 - nPos1 - 1)
	    strTagName = Replace(Replace(strTagName, vbCr, " "), vbLf, " ")

            nPos3 = InStr(strTagName, " ")
            If nPos3 > 0 Then
                strTagName = Left(strTagName, nPos3 - 1)
            End If
            
            If Left(strTagName, 1) = "/" Then
                strTagName = Mid(strTagName, 2)
                bSearchForBlock = False
            Else
                bSearchForBlock = True
            End If
            
            If InStr(1, TAGLIST, ";" & strTagName & ";", vbTextCompare) > 0 Then
                bRemove = True
                If bSearchForBlock Then
                    If InStr(1, BLOCKTAGLIST, ";" & strTagName & ";", vbTextCompare) > 0 Then
                        nPos2 = Len(strText)
                        nPos3 = InStr(nPos1 + 1, strText, "</" & strTagName, vbTextCompare)
                        If nPos3 > 0 Then
                            nPos3 = InStr(nPos3 + 1, strText, ">")
                        End If
                        
                        If nPos3 > 0 Then
                            nPos2 = nPos3
                        End If
                    End If
                End If
            Else
                bRemove = False
            End If
            
            If bRemove Then
                strResult = strResult & Left(strText, nPos1 - 1)
                strText = Mid(strText, nPos2 + 1)
            Else
                strResult = strResult & Left(strText, nPos1)
                strText = Mid(strText, nPos1 + 1)
            End If
        Else
            strResult = strResult & strText
            strText = ""
        End If
        
        nPos1 = InStr(strText, "<")
    Loop
    strResult = strResult & strText
	
    RemoveHTML = strResult
End Function


	Private Function EscapeRegExp(byVal sWord)
		Dim sTmp
		
		sTmp = Replace(sWord, "\", "\\")
		sTmp = Replace(sTmp, "^", "\^")
		sTmp = Replace(sTmp, ".", "\.")
		sTmp = Replace(sTmp, "*", "\*")
		sTmp = Replace(sTmp, "+", "\+")
		sTmp = Replace(sTmp, "]", "\]")
		sTmp = Replace(sTmp, "[", "\[")
		sTmp = Replace(sTmp, "}", "\}")
		sTmp = Replace(sTmp, "{", "\{")
		sTmp = Replace(sTmp, "(", "\(")
		sTmp = Replace(sTmp, ")", "\)")
		sTmp = Replace(sTmp, "$", "\$")
		sTmp = Replace(sTmp, "?", "\?")
		sTmp = Replace(sTmp, "|", "\|")
		EscapeRegExp = sTmp
	End Function

	Private Function PhraseFound(byVal toSrch, byVal toFind)
		'response.Write toSrch
		 ' check for an instance of the phrase
		 err.Clear
		 on error goto 0
		content = ""
		foundAt = 0
		'toSrch = RemoveASP(toSrch)
		toSrch = RemoveHTML(toSrch)
		
		
		foundAt = InStr(1, toSrch, Trim(toFind), 1)
		if(foundAt < (gs_PreviewSize/2) AND foundAt > 0)then
				foundAt = (gs_PreviewSize/2 + 1)
		end if		
		endpreview = gs_PreviewSize
		If foundAt <> 0 then
			content =  "" + Mid( toSrch, foundAt - (gs_PreviewSize/2), endpreview)
			PhraseFound = Highlight(content, toFind, "<b>", "</b>")
			Exit Function
		End If
		
		PhraseFound = content
		
	End Function

	Private Function MkTmpFile(ByVal sPath)
		Dim objTempFile
		
		Set objTempFile = objFSOSearch.OpenTextFile(sPath, 1, False)
		With objTempFile
			' read the whole file and return it
			MkTmpFile = .ReadAll
			' close the file
			.Close
		End With
		' release variable
		Set objTempFile = Nothing
	End Function

	Private Sub AddSearchResultRecord(byVal sPath, byVal sTitle, byVal sType, byVal sContent)
		on error goto 0 
		oRs.AddNew
		oRs.fields("Page_Path").value = sPath
		oRs.fields("Page_Title").value = sTitle
		oRs.fields("Page_Type").value = sType
		oRs.fields("Page_Content").value = sContent
		'response.write oRs.fields("Page_Content").value
		oRs.Update
	End Sub

	Private Sub ShowNoResults()
		With Response
			.Write("<P><CENTER><BIG><B>No Matches Found!</B></BIG></CENTER></P>")
			.Flush
		End With
	End Sub

	Private Sub ShowResults()
		Dim iRecordsShown

		oRs.MoveFirst
		oRs.AbsolutePage = iPageCurrent
		iRecordsShown = 0
		ShowPageNav
		do while not oRs.EOF and iRecordsShown < iPageSize
			With Response
				.Write("<A HREF=""" & UnEscapeApostrophe(oRs.Fields("Page_Path").value) & """><font size=4>" & _
					Server.HTMLEncode(UnEscapeApostrophe(oRs.Fields("Page_Title").value)) & "</font></A><BR><font color=gray>" & _
					UnEscapeApostrophe(RemoveASP(oRs.Fields("Page_Content").value)) & "</font><BR><A HREF=""" & _
					UnEscapeApostrophe(oRs.Fields("Page_Path").value) & _
					""">" & UnEscapeApostrophe(oRs.Fields("Page_Path").value) & "</A><BR><BR>")
				.Flush
			End With
			iRecordsShown = iRecordsShown + 1
			oRs.MoveNext
		Loop
		ShowPageNav
	End Sub

	Private Sub ShowPageNav()
		Dim i

		If bUseAsc Then sSortQS = sSortQS & "+ASC" Else sSortQS = sSortQS & "+DESC"
		Response.Write("<TABLE><TR><TD ALIGN=center><font size=2>")
		If iPageCurrent <> 1 Then
			Response.Write("<A HREF=""" & sBaseQS & sSortQS & "&page=" & _
			    iPageCurrent - 1 & """><b>Previous Page</b></A>&nbsp;&nbsp;")
		Else
			Response.Write("Page:&nbsp;")
		End If
		Response.Write("</TD><TD ALIGN=left><font size=2>")
		For i = 1 to iPageCount
			If i <> iPageCurrent Then
				Response.Write("<A HREF=""" & sBaseQS & sSortQS & _
				    "&page=" & i & """><font size=2>" & i & "</A>")
			Else
				Response.Write("<B>" & i & "</B>")
			End If
			If i <> iPageCount Then Response.Write("|")
		Next
		Response.Write("</TD><TD ALIGN=LEFT><font size=2>")
		If iPageCurrent < iPageCount Then
			Response.Write("&nbsp;&nbsp;<A HREF=""" & sBaseQS & sSortQS & _
			    "&page=" & iPageCurrent + 1 & """><b>Next Page</b></A>")
		Else
			Response.Write("&nbsp;")
		End If
		Response.Write("</TD></TR></TABLE><br>")
	End Sub

	Private Sub ShowDocsFound()
		Response.Write("(<B>" & oRs.RecordCount & _
		    "</B> documents found)<BR>")
	End Sub

	Private Sub ShowSortOptions
		Dim noShowPath, noShowTitle, noShowType
		Dim noShowASC, noShowDESC

		noShowPath = false
		noShowTitle = false
		noShowType = false
		noShowASC = false
		noShowDESC = false
		Response.Write("Sort:&nbsp;&nbsp;&nbsp;")
		select case Trim(LCase(Left(oRs.Sort, _
		    InStrRev(oRs.Sort, " "))))
			case "page_path": noShowPath = true
			case "page_title": noShowTitle = true
			case "page_type": noShowType = true
		end select
		select case Trim(LCase(Right(oRs.Sort, _
		    Len(oRs.Sort) - InStrRev(oRs.Sort, " "))))
			case "asc": noShowASC = True
			case "desc": noShowDESC = True
			case else: noShowASC = True
		end select
		if noShowTitle then
			Response.Write("<B>By Page Title</B>")
			ShowSubSortOptions noShowDESC, noShowASC
		else
			Response.Write("<A HREF=""" & sBaseQS & _
			    "&sort=" & server.urlencode("Page_Title") & _
			    "+ASC"">By Page Title</A>")
		end if
		Response.Write("&nbsp;&nbsp;&#149;&#149;&nbsp;&nbsp;")
		if noShowPath then
			Response.Write("<B>By Page Path</B>")
			ShowSubSortOptions noShowDESC, noShowASC
		else
			Response.Write("<A HREF=""" & _
			    sBaseQS & "&sort=" & _
			    server.urlencode("Page_Path") & _
			    "+ASC"">By Page Path</A>")
		end if
		Response.Write("&nbsp;&nbsp;&#149;&#149;&nbsp;&nbsp;")
		if noShowType then
			Response.Write("<B>By Page Type</B>")
			ShowSubSortOptions noShowDESC, noShowASC
		else
			Response.Write("<A HREF=""" & _
			    sBaseQS & "&sort=" & _
			    server.urlencode("Page_Type") & _
			    "+ASC"">By Page Type</A>")
		end if
		Response.Write("<BR>")
	End Sub

	Private Sub ShowSubSortOptions(ByVal noShowDESC, ByVal noShowASC)
		Response.Write("&nbsp;&nbsp;[")
		If InStr(sSortQS, "+") <> 0 Then
			sSortQS = Trim(Left(sSortQS, InStrRev(sSortQS, "+") - 1))
		Else
			sSortQS = Trim(Left(sSortQS, InStrRev(sSortQS, " ") - 1))
		End If
		If noShowDESC then
			Response.Write("<A HREF=""" & _
			    sBaseQS & sSortQS & "+ASC"">ASC</A>")
			Response.Write("&nbsp;|&nbsp;")
			Response.Write("<I>DESC</I>")
		End if
		If noShowASC Then
			Response.Write("<I>ASC</I>")
			Response.Write("&nbsp;|&nbsp;")
			Response.Write("<A HREF=""" & sBaseQS & _
			    sSortQS & "+DESC"">DESC</A>")
		End If
		Response.Write("]")
	End Sub

	Private Sub ResolveSortPattern
		select case Trim(Request("sort")) 
			case ""
				oRs.Sort = "Page_Title ASC"
			case else
				On Error Resume Next
				oRs.Sort = Request("sort")
				If Err Then
					Err.Clear
					oRs.Sort = "Page_Title ASC"
				End If
				On Error GoTo 0
		end select
		sSortQS = "&sort=" & server.urlencode(oRs.Sort)
	End Sub

	Private Function EscapeApostrophe(byVal sIn)
		EscapeApostrophe = Replace(sIn, "'", "''")
	End Function

	Private Function UnEscapeApostrophe(byVal sIn)
		UnEscapeApostrophe = Replace(sIn, "''", "'")
	End Function

	Private Function Title(byVal textToSearch)
		Dim re, Matches, tmp, bNoMatch, match

		bNoMatch = false
		Set re = New RegExp
		With re
			.ignorecase = true
			.global = false
			.Pattern = "<title>(.*)</title>"

		on error resume next
			Set Matches = .execute(trim(textToSearch))
		on error goto 0
		End With

		if err then
			tmp = ""
			bNoMatch = true
		else
			for each match in matches
			tmp = lcase(match.value)
			tmp = replace(tmp, "<title>", "")
			tmp = replace(tmp, "</title>", "")
			tmp = replace(tmp, "the asp emporium -", "")
			tmp = replace(tmp, "the asp emporium :", "")
			tmp = replace(tmp, "the asp emporium:", "")
			tmp = replace(tmp, "the asp emporium &gt; " & _
				"useful asp routines &gt;", "")
			tmp = replace(tmp, "the asp emporium &gt; " & _
				"code library &gt;", "")
			tmp = replace(tmp, "the asp emporium &gt;", "")
			tmp = replace(tmp, "(.*)", "")
			tmp = trim(tmp)
			exit for
			next
		end if

		if not bNoMatch then Set Matches = Nothing
		Set re = Nothing
		if trim(tmp) = "" then tmp = "No Title Available..."
		Title = PCase(tmp)
	End Function

	Private Function PCase(byVal raw)
		dim tmp, i, first, others

		tmp = split(raw, " ")
		for i = 0 to ubound(tmp)
			first = ""
			others = ""
			first = UCase(left(tmp(i), 1))
			others = LCase(mid(tmp(i), 2))
			tmp(i) = CStr(first & others)
		next
		PCase = Join(tmp, " ")
	End Function

	Private Function CreateHTTPpath(strInput)
		 ' this function takes a mappath path and
		 ' makes it usable as a link to an actual file
		Dim strRoot, strRoot2

		strRoot = server.mappath("/")
		strRoot2 = replace(lcase(strInput), lcase(strRoot), "")
		CreateHTTPpath = replace(strRoot2, "\", "/")
	End Function

	Private Function DefineLink(strPath)
		 ' try to figure out what type of file this is
		 ' based on the path
		Dim sPath

		sPath = CreateHTTPPath(strPath)
		sPath = Mid(sPath, 1, InStrRev(sPath, "/"))
		DefineLink = TranslatePath(sPath)
	End Function

	Private Function TranslatePath(strInput)
		 ' translate the example folder
		 ' to a more descriptive phrase
		Select Case LCASE(strInput)
			Case "/aspemporium/help/"

				TranslatePath = "ASP Tips and Hints (Help)"

			Case "/aspemporium/tutorials/", _
			     "/aspemporium/tutorials/ssi/"

				TranslatePath = "ASP or VBSCRIPT Tutorial"

			Case "/aspemporium/codelib/"

				TranslatePath = "VBScript Code Library"

			Case "/aspemporium/examples/jscript/"

				TranslatePath = "JScript ASP Example"

			Case "/aspemporium/examples/", _
			     "/aspemporium/search/", _
			     "/aspemporium/examples/easyads/", _
			     "/aspemporium/examples/numberarraytool/", _
			     "/aspemporium/examples/quiz/", _
			     "/aspemporium/examples/xmlcatalog/"

				TranslatePath = "VBScript ASP Example"

			case "/aspemporium/help/err/db/", _
			     "/aspemporium/help/err/vbs/", _
			     "/aspemporium/help/err/asp/", _
			     "/aspemporium/help/err/"

				TranslatePath = "HELP - Listing of " & _
				    "Fixes by Error Message"

			Case "/aspemporium/index/"
				TranslatePath = "ASP Emporium Site Index"

			Case Else
				TranslatePath = strInput
		End Select
	End Function
End Class
%>

<script language=jscript runat=server>
function RemoveASP(toSrch) {
	//remove all ASP code from a given string

	//find all instances of an ASP script start tag
	var re = /(\<\%)/gi
	var out = "", last = 0, arr, i = 0;
	var ar1 = new Array(), ar2 = new Array();
	//loop through the instances and save them
	//into an array...
	while ((arr = re.exec(toSrch)) != null) {
		ar1[i] = arr.index
		i++
	}
	//find all instances of an ASP script end tag
	re = /(\%\>)/gi
	i = 0;
	//loop through the instances and save them
	//into an array...
	while ((arr = re.exec(toSrch)) != null) {
		ar2[i] = arr.index
		i++
	}
	//build the return string...
	for (i=0;i<ar1.length;i++) {
		//this time, take everything but the ASP code...
		out += toSrch.substr(ar2[i] + 2, ar1[i + 1] - ar2[i] - 2);
		last = i
	}
	//make sure to grab that last bit of the HTML after
	//the last ASP block...
	out += toSrch.substr(ar2[last] + 2)
	return out;
}
</script>